==> billogram-foundation-3.13.5.tgz: package/modules/components/datepicker/DatepickerRangeContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';

import { datepickerShape } from './utils/propTypes';


export default ({
    block,
    Component
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(Component !== undefined, 'Missing Datepicker component');

    return React.createClass({

        displayName: `${Component.displayName}Range`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string,
            end: PropTypes.shape(datepickerShape),
            start: PropTypes.shape(datepickerShape)
        },

        render() {
            const { actionTypePrefix, customActionMetadata, path, root, start, end } = this.props;
            return (
                <div className={ block() }>
                    <Component
                        { ...start }
                        actionTypePrefix={ isNullOrEmpty(actionTypePrefix) ? actionTypePrefix : `${actionTypePrefix}-START` }
                        customActionMetadata={ customActionMetadata }
                        path={ `${path}.start` }
                        root={ root } />
                    <span className={ block('separator') }>&#65293;</span>
                    <Component
                        { ...end }
                        actionTypePrefix={ isNullOrEmpty(actionTypePrefix) ? actionTypePrefix : `${actionTypePrefix}-END` }
                        customActionMetadata={ customActionMetadata }
                        path={ `${path}.end` }
                        root={ root } />
                </div>
            );
        }

    });

};

==> billogram-foundation-3.13.10.tgz: package/modules/components/datepicker/DatepickerRangeContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';


export default ({
    block,
    Component
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(Component !== undefined, 'Missing Datepicker component');

    return React.createClass({

        displayName: `${Component.displayName}Range`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string,
            // Using object for 'end' and 'start' since it's going to be validated by the underlying datepicker component.
            end: PropTypes.object,
            start: PropTypes.object
        },

        render() {
            const { actionTypePrefix, customActionMetadata, path, root, start, end } = this.props;
            return (
                <div className={ block() }>
                    <Component
                        { ...start }
                        actionTypePrefix={ isNullOrEmpty(actionTypePrefix) ? actionTypePrefix : `${actionTypePrefix}-START` }
                        customActionMetadata={ customActionMetadata }
                        path={ `${path}.start` }
                        root={ root }
                        ui="transparent" />
                    <span className={ block('separator') }>&#65293;</span>
                    <Component
                        { ...end }
                        actionTypePrefix={ isNullOrEmpty(actionTypePrefix) ? actionTypePrefix : `${actionTypePrefix}-END` }
                        customActionMetadata={ customActionMetadata }
                        path={ `${path}.end` }
                        root={ root }
                        ui="transparent" />
                </div>
            );
        }

    });

};
